summaryrefslogtreecommitdiff
path: root/sys
diff options
context:
space:
mode:
authorMike Belopuhov <mikeb@cvs.openbsd.org>2012-05-23 08:23:44 +0000
committerMike Belopuhov <mikeb@cvs.openbsd.org>2012-05-23 08:23:44 +0000
commitdac322837d91418e6d6519e9fa9c857b3becf6d8 (patch)
tree72476db9ab2f14ce6256191ff447c1b54ddb1f0e /sys
parentebd763dfb5f101b9f881901b1473006e2c442793 (diff)
increase the number of io and mem extent regions for amd64 to 16
as it was done for i386 some time ago; update the comment in the i386 code to reflect reality. this helps machines with plenty of memory regions set up by the bios. ok kettenis, jsg
Diffstat (limited to 'sys')
-rw-r--r--sys/arch/amd64/amd64/bus_space.c8
-rw-r--r--sys/arch/i386/i386/machdep.c4
2 files changed, 6 insertions, 6 deletions
diff --git a/sys/arch/i386/i386/machdep.c b/sys/arch/i386/i386/machdep.c
index 4495a83e55d..521a4570f80 100644
--- a/sys/arch/i386/i386/machdep.c
+++ b/sys/arch/i386/i386/machdep.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: machdep.c,v 1.509 2012/03/27 06:44:01 jsg Exp $ */
+/* $OpenBSD: machdep.c,v 1.510 2012/05/23 08:23:43 mikeb Exp $ */
/* $NetBSD: machdep.c,v 1.214 1996/11/10 03:16:17 thorpej Exp $ */
/*-
@@ -251,7 +251,7 @@ void (*initclock_func)(void) = i8254_initclocks;
/*
* Extent maps to manage I/O and ISA memory hole space. Allocate
- * storage for 8 regions in each, initially. Later, ioport_malloc_safe
+ * storage for 16 regions in each, initially. Later, ioport_malloc_safe
* will indicate that it's safe to use malloc() to dynamically allocate
* region descriptors.
*
diff --git a/sys/arch/amd64/amd64/bus_space.c b/sys/arch/amd64/amd64/bus_space.c
index 4b476ae2cf1..9367314e579 100644
--- a/sys/arch/amd64/amd64/bus_space.c
+++ b/sys/arch/amd64/amd64/bus_space.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: bus_space.c,v 1.19 2011/04/09 21:30:27 jsg Exp $ */
+/* $OpenBSD: bus_space.c,v 1.20 2012/05/23 08:23:43 mikeb Exp $ */
/* $NetBSD: bus_space.c,v 1.2 2003/03/14 18:47:53 christos Exp $ */
/*-
@@ -45,7 +45,7 @@
/*
* Extent maps to manage I/O and memory space. Allocate
* storage for 8 regions in each, initially. Later, ioport_malloc_safe
* will indicate that it's safe to use malloc() to dynamically allocate
* region descriptors.
*
@@ -55,8 +55,8 @@
* The extent maps are not static! Machine-dependent ISA and EISA
* routines need access to them for bus address space allocation.
*/
-static long ioport_ex_storage[EXTENT_FIXED_STORAGE_SIZE(8) / sizeof(long)];
-static long iomem_ex_storage[EXTENT_FIXED_STORAGE_SIZE(8) / sizeof(long)];
+static long ioport_ex_storage[EXTENT_FIXED_STORAGE_SIZE(16) / sizeof(long)];
+static long iomem_ex_storage[EXTENT_FIXED_STORAGE_SIZE(16) / sizeof(long)];
struct extent *ioport_ex;
struct extent *iomem_ex;
static int ioport_malloc_safe;
@@ -45,7 +45,7 @@
/*
* Extent maps to manage I/O and memory space. Allocate
- * storage for 8 regions in each, initially. Later, ioport_malloc_safe
+ * storage for 16 regions in each, initially. Later, ioport_malloc_safe
* will indicate that it's safe to use malloc() to dynamically allocate
* region descriptors.